package mi.hdm.recipes;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.util.List;
import java.util.Optional;

public class RecipeManager {
    private final List<Recipe> recipes;
    private final CategoryManager categories;
    private final IngredientManager ingredients;
    private final NutritionCalculator nutritionCalculator;
    private static final Logger log = LogManager.getLogger(RecipeManager.class);

    public RecipeManager(List<Recipe> recipes, CategoryManager categories, IngredientManager ingredients, NutritionCalculator nutritionCalculator) {
        this.recipes = recipes;
        this.categories = categories;
        this.ingredients = ingredients;
        this.nutritionCalculator = nutritionCalculator;
    }

    public void addRecipe(Recipe recipe){
        recipes.add(recipe);
    }

    public Recipe deleteRecipe(int i) {
        return recipes.remove(i);
    }

    public boolean deleteRecipe(String name) {
        Recipe r = getRecipeByName(name).orElseThrow();
        return recipes.remove(r);
    }

    public RecipeEditor editRecipe (int i) {
        Recipe recipe = recipes.get(i);
        return new RecipeEditor(recipe);
    }

    public RecipeEditor editRecipe (String name) {
        Recipe recipe = getRecipeByName(name).orElseThrow();
        return new RecipeEditor(recipe);
    }

    public RecipeEditor editRecipe(Recipe recipe) {
        return new RecipeEditor(recipe);
    }


    private Optional<Recipe> getRecipeByName(String name) {
        for (final Recipe r : recipes) {
            if (name.equals(r.getName())) {
                return Optional.of(r);
            }
        }
        return Optional.empty();
    }

}
